page_setup

Function page_setup 

pub fn page_setup(
    page: QualityPage,
    plan: &DataQualityPlan,
    results: Option<&DataQualityResults>,
    has_time_columns: bool,
) -> Option<QualitySetup>
The plan setting a result page needs before it has anything to show, if any. Intervals need time roles, and ask only when there are dates to assign.