pub fn test_all(
values: &[f64],
seed: u64,
) -> Vec<(DistributionType, FitOutcome)>Expand description
Test every family, in parallel: each is independent, and each is a few hundred thousand CDF evaluations.
pub fn test_all(
values: &[f64],
seed: u64,
) -> Vec<(DistributionType, FitOutcome)>Test every family, in parallel: each is independent, and each is a few hundred thousand CDF evaluations.