check_intent

Function check_intent 

pub fn check_intent(
    intent: &ColumnIntent,
    dtype: &DataType,
    time: Option<&TimeInterpretation>,
) -> Result<(), String>
Why intent cannot be measured on a column of dtype, said on the form: a bound that is not a value of the column’s kind, or a minimum above the maximum.