pub fn check_choices(report: &QualityReport) -> Vec<(&'static str, usize)>Expand description
The checks that made a finding in report, each with how many, most important
first.
pub fn check_choices(report: &QualityReport) -> Vec<(&'static str, usize)>The checks that made a finding in report, each with how many, most important
first.