pub fn next_window(start: NaiveDateTime, every: &str) -> Option<NaiveDateTime>Expand description
The start of the window after the one starting at start.
pub fn next_window(start: NaiveDateTime, every: &str) -> Option<NaiveDateTime>The start of the window after the one starting at start.