collect_lazy

Function collect_lazy 

pub fn collect_lazy(
    lf: LazyFrame,
    use_streaming: bool,
) -> Result<DataFrame, PolarsError>
Collect a LazyFrame, with the streaming engine when the streaming feature is on and use_streaming asks. Returns PolarsError for callers that store or show it (e.g. DataTableState::error).