Module value_counts_modal

Module value_counts_modal 

State of the Value Counts screen: which column, the counts read for the view, the order, the cursor, and the count in flight.

Structs

Computing
A count being read.
ValueCountsModal

Enums

CountsView
What the screen shows of the counts.