hex_width

Function hex_width 

pub fn hex_width(n: usize) -> usize
Columns the hex bytes of a row of n take: a space between bytes, one more between groups of four, and another between groups of eight.