of

Function of 

pub fn of(
    state: &DataTableState,
    paths: &[PathBuf],
    options: &OpenOptions,
) -> Option<Tables>
The tables of the dataset state opened from paths with options: None for a source of one table, or several files.