pub fn several(
state: &DataTableState,
paths: &[PathBuf],
options: &OpenOptions,
) -> boolExpand description
Whether of would list more than one table, without listing them: asked by the
footer each frame.
pub fn several(
state: &DataTableState,
paths: &[PathBuf],
options: &OpenOptions,
) -> boolWhether of would list more than one table, without listing them: asked by the
footer each frame.