pub fn detail(audio: &AudioSource) -> DetailExpand description
The Audio tab: the file’s format, size and length, then its metadata (bext, iXML,
LIST INFO, AIFF text) and markers, markers last.
pub fn detail(audio: &AudioSource) -> DetailThe Audio tab: the file’s format, size and length, then its metadata (bext, iXML,
LIST INFO, AIFF text) and markers, markers last.