pub fn parse_entra_token(text: &str) -> Option<(String, SystemTime)>Expand description
The access token and expiry from an Entra ID token response.
pub fn parse_entra_token(text: &str) -> Option<(String, SystemTime)>The access token and expiry from an Entra ID token response.