pub fn render(
figure: &Figure,
options: &ExportOptions,
format: ChartExportFormat,
) -> Result<Vec<u8>>Expand description
The figure in format, as the bytes of the file.
pub fn render(
figure: &Figure,
options: &ExportOptions,
format: ChartExportFormat,
) -> Result<Vec<u8>>The figure in format, as the bytes of the file.