parse_args

Function parse_args 

pub fn parse_args<I, T>(argv: I) -> Result<Args, String>
where I: IntoIterator<Item = T>, T: Into<OsString> + Clone,
argv read as the command line is, for a host such as the Python binding that spells its options as flags and -c. The error is clap’s, on one line.