pub fn destination(
choice: BackendChoice,
osc52_limit: usize,
) -> Result<Box<dyn Destination>, String>Expand description
The destination a backend choice names, built at the first copy.
pub fn destination(
choice: BackendChoice,
osc52_limit: usize,
) -> Result<Box<dyn Destination>, String>The destination a backend choice names, built at the first copy.