pub trait Destination {
// Required methods
fn write(&mut self, payload: Payload) -> Result<(), String>;
fn describe(&self) -> &'static str;
// Provided method
fn accepts(&self) -> Accepts { ... }
}Expand description
Somewhere a payload can go. A trait so the integration tests can hand the app a destination that only records what it was given.
Required Methods
Provided Methods
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".