is_folder_marker

Function is_folder_marker 

pub fn is_folder_marker(name: &str, size: u64, prefixes: &[String]) -> bool
Whether a listed object is only a folder marker. Accounts with hierarchical namespace list every directory twice, once as a prefix and once as an empty blob of the same name; the blob is not data.