narrowing_prefix

Function narrowing_prefix 

pub fn narrowing_prefix(filter: &str, names: &[&str]) -> Option<String>
The server-side prefix a home filter can ask a cut-short level for, if any. The filter is fuzzy and the prefix literal, so it asks for the names’ shared part up to their last separator (STATION=, year=) plus the filter, in the names’ case; a filter already spelling the shared part is taken as typed.