find_program

Function find_program 

pub fn find_program(
    program: &str,
    path: &OsStr,
    pathext: Option<&str>,
    windows: bool,
) -> Option<PathBuf>
Where program would be run from: itself when it names a path, else the first match on path. On Windows each PATHEXT extension is tried too, which is how gcloud finds gcloud.cmd.