pub fn load(cloud: &CloudConfig, dir: &Path) -> Vec<String>
Read the files cloud.env_files names, relative to dir, and keep their cloud variables for var. Returns a note for each file that could not be read.
cloud.env_files
dir
var