pub fn rediscover(config: &CloudConfig) -> Arc<[Source]> ⓘExpand description
The sources on this machine discovered again, as Ctrl+R asks: a login made since is found.
pub fn rediscover(config: &CloudConfig) -> Arc<[Source]> ⓘThe sources on this machine discovered again, as Ctrl+R asks: a login made since is found.