pub fn session_sources(config: &CloudConfig) -> Arc<[Source]> ⓘExpand description
The sources on this machine for config, discovered once for the session.
pub fn session_sources(config: &CloudConfig) -> Arc<[Source]> ⓘThe sources on this machine for config, discovered once for the session.