pub fn configurations(env: &Environment<'_>) -> Vec<Configuration>Expand description
Every configuration, the active one first, then by name.
pub fn configurations(env: &Environment<'_>) -> Vec<Configuration>Every configuration, the active one first, then by name.