pub fn preview(ty: &ColumnType, value: &str) -> Option<String>Expand description
value read as ty, as the table would show it: 2024-03-04 for 03/04/2024 as a
date with %d/%m/%Y. None when it does not read.
pub fn preview(ty: &ColumnType, value: &str) -> Option<String>value read as ty, as the table would show it: 2024-03-04 for 03/04/2024 as a
date with %d/%m/%Y. None when it does not read.