pub fn segment_order(
results: &DataQualityResults,
by_change: bool,
) -> Vec<usize>Expand description
The order Segments lists its rows in: as they fall, or the clearest change first (ties, and segments with no clear change, keep their order).