database_rows

Function database_rows 

pub fn database_rows(file: &Path) -> Vec<Entry>
The rows of a file of tables’ listing on the home screen: a database’s tables and views, or an archive’s arrays, by name, as a directory lists its files, SQLite’s own marked to be hidden, each at its path inside the file.