how_read

Function how_read 

pub fn how_read(entry: &Entry) -> Option<HowRead>
How opening entry will read it, as crate::FileFormat::read_mode says for its format and how it is stored, and whether a remote one is downloaded first. None for anything but a file whose name says its format.