pub fn name_spec_file(entry: &mut Entry, spec: &Spec)
Name entry a file of spec, which reads it; a spec that reads its records as several variants makes it a place too, whose tables → lists.
entry
spec