pub fn partition_layout(dir: &Path) -> Option<Partitions>Expand description
Describe how a hive dataset is partitioned, from directory names alone.
pub fn partition_layout(dir: &Path) -> Option<Partitions>Describe how a hive dataset is partitioned, from directory names alone.