pub fn table_row(path: &Path) -> Option<Entry>
The row of a table inside a file of tables named by its path (app.db/users), as a recent is listed: None when the path names no table of such a file.
app.db/users
None