variant_row

Function variant_row 

pub fn variant_row(path: &Path, formats: &Registry) -> Option<Entry>
The row of a variant named by its path inside its file (day.itch/add), as a recent is listed: None when the path names no variant of such a file.