pub fn conversion_failure(err: &PolarsError) -> Option<ConversionFailure>Expand description
The conversion that failed, if that is what err is.
pub fn conversion_failure(err: &PolarsError) -> Option<ConversionFailure>The conversion that failed, if that is what err is.