located_message

Function located_message 

pub fn located_message(
    path: Option<&Path>,
    at: Option<(usize, usize)>,
    what: &str,
) -> String
file_message, with the line and column the problem is at, when it is at one place: "spec.toml":3:7: <what went wrong>. Without a path, the location and the sentence alone.