sentence

Function sentence 

pub fn sentence(what: &str) -> String
what as a sentence: its first letter capitalized and its first line ended with a full stop. The lines after it are kept as they are.