pub fn list_preview(items: &Series) -> StringExpand description
How the table previews a list cell: its first ten items, and how many there
are when that is not all of them ([a, b...] (12 items)). Past
CELL_PREVIEW_BYTES, more than a cell shows, it stops with ....