str_value

Function str_value 

pub fn str_value<'a>(value: &AnyValue<'a>) -> Cow<'a, str>
AnyValue::str_value, which panics on a date past the calendar, with such a value written as its stored number, and a list or struct holding one written as nested_compact does.