detail

Function detail 

pub fn detail<RS: Read + Seek>(
    workbook: &mut Sheets<RS>,
    opened: &str,
    range: &Range<Data>,
) -> Detail
The Excel tab of the Info panel for a workbook whose sheet opened was read as range: each sheet’s range, the opened one’s from its cells and the others’ as their files declare it or as the open already parsed them.