refusal

Function refusal 

pub fn refusal(
    format: Option<FileFormat>,
    options: &OpenOptions,
) -> Option<String>
Why format cannot be followed, or None when it can. Only text read line by line, and an Arrow IPC stream (see [followed_stream]), can: a file whose footer is written last (Parquet, an Arrow IPC file, Excel) cannot be read before it is finished, and a compressed one cannot be read from the middle.