pub struct SignalReport {}Expand description
What AudioSource::signal_report measured of one channel.
Fields
channel: Stringframes: u64full_scale: (f64, f64)The values at or past which a sample is at full scale, in the column’s units.
at_full_scale: u64Samples at full scale, in runs or not.
clip_run_min: u64The shortest run counted, and the runs of at least that many samples at full scale, the samples in them, and the longest.
clip_runs: u64in_clip_runs: u64longest_clip: u64zero_run_min: u64The shortest run of exact zeros counted (10 ms, and at least 16 samples), and the runs that long, the samples in them, and the longest.
zero_runs: u64in_zero_runs: u64longest_zeros: u64mean: f64The channel’s mean, in the column’s units.