check_comment_char

Function check_comment_char 

pub fn check_comment_char(c: &str) -> Result<(), String>
Why c cannot mark comment lines, if it cannot: it must be something, and on one line. --comment, its config key and the Python option share it.