pub fn columns(
index: &Index,
t: &MessageType,
) -> (Vec<ColumnLayout>, Vec<(String, String)>)Expand description
The columns of a message type, and each one’s unit.
pub fn columns(
index: &Index,
t: &MessageType,
) -> (Vec<ColumnLayout>, Vec<(String, String)>)The columns of a message type, and each one’s unit.