decode

Function decode 

pub fn decode(
    bytes: &[u8],
    column: &ColumnLayout,
    rows: usize,
) -> PolarsResult<Column>
The first rows values of column from bytes: one cell a row, an Array of column.count values each when it holds more than one. Asking for more rows than bytes holds is an error.