decode_at

Function decode_at 

pub fn decode_at(
    bytes: &[u8],
    column: &ColumnLayout,
    records: &[usize],
) -> PolarsResult<Column>
The values of column from bytes for records starting at records, in order (column.start into each; stride unused): for unevenly spaced records like log messages found by an index. A cell past the end is an error.