decode_rows

Function decode_rows 

pub fn decode_rows(
    bytes: &[u8],
    column: &ColumnLayout,
    index: &IdxCa,
) -> PolarsResult<Column>
The values of column from bytes for the rows index names, in that order. A missing row, or one bytes does not hold, is an error.