pick

Function pick 

pub fn pick(listed: &[&str], table: Option<&str>) -> Result<Splits, String>
The split of listed an open reads, table if given, else the first in offered order, and the others in that order: train, validation and test, then the rest as listed.