Log

Trait Log 

pub trait Log:
    Any
    + Send
    + Sync
    + Sized {
    const EMPTY: &'static str;

    // Required methods
    fn index(data: &[u8]) -> Result<Self, String>;
    fn tables(&self) -> Vec<Table>;
    fn detail(&self) -> Detail;
    fn notes(&self) -> Vec<String>;
    fn table(
        &self,
        bytes: Arc<Bytes>,
        name: &str,
        opened: &mut Opened,
    ) -> Result<LazyFrame, String>;
}
A log of record types one pass indexes, each type a table: a flight log. A new one is this and a READER with scan and listed.

Required Associated Constants

const EMPTY: &'static str

Said after “the file holds no tables.” of a log with none.

Required Methods

fn index(data: &[u8]) -> Result<Self, String>

fn tables(&self) -> Vec<Table>

Its tables, for the home screen and --table.

fn detail(&self) -> Detail

What the Info panel’s tab of it says.

fn notes(&self) -> Vec<String>

What the Notes tab says of the pass.

fn table( &self, bytes: Arc<Bytes>, name: &str, opened: &mut Opened, ) -> Result<LazyFrame, String>

The table name, one of Self::tables, read from bytes, filling what of opened it knows (its window, units).

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors

Source

impl Log for datui_lib::formats::dataflash::Index

Source

const EMPTY: &'static str = " The log has no records but its formats."

Source

impl Log for datui_lib::formats::ulog::Index

Source

const EMPTY: &'static str = " The log has no data messages."