guess_file

Function guess_file 

pub fn guess_file(
    path: &Path,
    compression: Option<CompressionFormat>,
) -> Option<FileFormat>
guess for the local file at path, through its compression. What is inside a compressed file is read through it only as delimited text or lines.