split_variant

Function split_variant 

pub fn split_variant(
    path: &Path,
    formats: &Registry,
) -> Option<(PathBuf, String)>
The file and the variant a path inside a file of a format spec’s variants names: day.itch/add is the variant add of day.itch, as the spec writes it. None for a path that is there, inside no such file, or naming no variant of it.