pub fn notes(summary: &MidiSummary) -> Vec<Note>Expand description
What the open has to say about the events: notes that never end, and files that could not be read.
pub fn notes(summary: &MidiSummary) -> Vec<Note>What the open has to say about the events: notes that never end, and files that could not be read.