open_in

Function open_in 

pub fn open_in(
    bytes: Arc<Bytes>,
    at: usize,
    len: usize,
    name: &str,
) -> Result<Array, String>
The array whose .npy bytes start at bytes into bytes (the whole of a file, or a member stored in an archive) and run for len bytes, its one column named name.