pub fn column_bytes_per_row( footers: &[Option<FileFooter>], ) -> Vec<(String, usize)>
Uncompressed bytes per row of each column over the footers read; files without a column count its rows as zero (they read null).