open_table

Function open_table 

pub fn open_table(
    file: &Path,
    display: &Path,
    table: &Table,
    others: &[Table],
) -> Result<Opened>
Open table of database file (shown as display) in place: its frame, the pushdown for filters and sort, and the hold that stops its statements when released. others are the other tables, for Info.