pick

Function pick 

pub fn pick(
    tables: Vec<Table>,
    wanted: Option<&str>,
    display: &Path,
) -> Result<Pick>
The table wanted names among tables, or the database’s one table of its own when nothing is named. display names the database in errors.