pub struct SpecError {
pub path: Option<PathBuf>,
pub line: usize,
pub column: usize,
pub message: String,
}Expand description
A problem with a spec: where it is (file, line, column) and what was expected.
Fields
path: Option<PathBuf>line: usizeOne-based; 0 when the problem is not at one place in the text.
column: usizemessage: StringTrait Implementations
Sourceimpl Display for SpecError
Said as every reader error is, with the place in the text a compiler gives:
"spec.toml":3:7: <what went wrong>.
impl Display for SpecError
Said as every reader error is, with the place in the text a compiler gives:
"spec.toml":3:7: <what went wrong>.
impl Eq for SpecError
Sourceimpl Error for SpecError
impl Error for SpecError
1.30.0 · Sourcefn source(&self) -> Option<&(dyn Error + 'static)>
fn source(&self) -> Option<&(dyn Error + 'static)>
Returns the lower-level source of this error, if any. Read more
1.0.0 · Sourcefn description(&self) -> &str
fn description(&self) -> &str
👎Deprecated since 1.42.0:
use the Display impl or to_string()
impl StructuralPartialEq for SpecError