pub fn init(mode: UnicodeMode)Expand description
Choose the glyph set for this run. Later calls are ignored, so this is safe to call once from startup and never think about again.
pub fn init(mode: UnicodeMode)Choose the glyph set for this run. Later calls are ignored, so this is safe to call once from startup and never think about again.