catalog_entry_for

Function catalog_entry_for 

pub fn catalog_entry_for(
    catalogs: &[ShownCatalog],
    path: &Path,
) -> Option<(String, Arc<Dataset>)>
The catalog entry path is or is inside, with its catalog’s label: the innermost, or the first listed of two at one place.