pub fn run(program: &Program, path: &Path) -> Result<()>
Run program on path: wait for one that takes the terminal, start one that does not. The caller has handed the terminal over for a wait.
program
path