json_copy_text

Function json_copy_text 

pub fn json_copy_text(value: &Value, cap: usize) -> Option<String>
A JSON value as copy text: text as itself, a null as empty, anything else as JSON, indented when it is an object or array. None when it is over cap bytes.