pub fn hex_per_line(width: usize) -> usize
Bytes to a hex row at width cells: 32 where a row of them fits, then 16, 8, 4. A row of n is the offset and a space, three cells a byte, two spaces, and a cell a byte.
width
n