refuse

Function refuse 

pub fn refuse(paths: &[PathBuf], piped: bool) -> Option<&'static str>
Why standard input cannot be read as asked, before anything is read: nothing is piped in, or it is named with other paths.