init

Function init 

pub fn init(settings: &LogSettings) -> Option<String>
Open the log and install the logger and Polars warning hook; repeatable (the Python binding runs the TUI per view), latest settings winning. Returns the message for the user if the log cannot open, unprinted since stderr may be that log.