pub fn holder(path: &Path) -> Option<FileFormat>Expand description
The format of a file that can hold several tables, by its first bytes (and, for a NumPy archive, its name: a zip file is many things).
pub fn holder(path: &Path) -> Option<FileFormat>The format of a file that can hold several tables, by its first bytes (and, for a NumPy archive, its name: a zip file is many things).