variants

Function variants 

pub fn variants(file: &Path, formats: &Registry) -> Option<(String, Vec<Table>)>
The variants of the records of file, as the format spec whose glob names it reads them, each a table: the spec’s name, and its variants with their columns. None unless the spec reads several. Its name is all that is read.