pub fn detail(midi: &MidiSummary) -> DetailExpand description
The MIDI tab: the header, timing and tempo, then the tracks; for a directory of songs, the totals, then the files that could not be read.
pub fn detail(midi: &MidiSummary) -> DetailThe MIDI tab: the header, timing and tempo, then the tracks; for a directory of songs, the totals, then the files that could not be read.