read_remote_model

Function read_remote_model 

pub fn read_remote_model(
    urls: &[String],
    format: FileFormat,
    remote: &Remote<'_>,
) -> Result<(LazyFrame, ModelSummary), RangeError>
Read urls — remote model files, or SafeTensors indexes that name them — as one table of tensors, as read_model reads files on disk, fetching only their headers. RangeError::NoRanges only for one file named on its own, which can be downloaded instead; for shards it is an error that says so.