pub fn text_buffer(path: &Path) -> Result<Option<Buffer<u8>>>
The text of the file at path as a buffer Polars scans in place, when the file ends in NULs; None when it does not, and the file is scanned by its path.
path
None