display_width

Function display_width 

pub fn display_width(
    fmt: &CellFormatter,
    value: &AnyValue<'_>,
    scratch: &mut String,
) -> usize
A value’s on-screen cells without building its string where possible (integers); others are rendered and measured as the table measures them.