pub fn formatted(series: &Series, format: &str) -> PolarsResult<Series>Expand description
Polars’ dt.to_string(format), with a date or datetime past the calendar as
its stored number.
pub fn formatted(series: &Series, format: &str) -> PolarsResult<Series>Polars’ dt.to_string(format), with a date or datetime past the calendar as
its stored number.