pub fn compared_bar(
view: &TrendView<'_>,
bar: usize,
plan: &DataQualityPlan,
) -> Option<usize>Expand description
The bar a bar is compared with: the one holding the baseline segment when the plan compares with one, and otherwise the bar before.