pub fn window_label(column: &str, every: &str, start: NaiveDateTime) -> StringExpand description
A window’s label, as a run names the window starting at start.
pub fn window_label(column: &str, every: &str, start: NaiveDateTime) -> StringA window’s label, as a run names the window starting at start.