parse_query_over

Function parse_query_over 

pub fn parse_query_over(
    query: &str,
    schema: Option<&Schema>,
) -> Result<ParsedQuery, String>
parse_query for data of schema: timestamp literals against zoned columns read in that zone, and temporal columns compared with quoted text are errors.