sanitize_buffer

Function sanitize_buffer 

pub fn sanitize_buffer(buf: &mut Buffer)
Replace control characters in every cell of a finished buffer: once, after all rendering, before the backend, the last point datui controls the output.