random_sample

Function random_sample 

pub fn random_sample(files: usize, n: usize, seed: u64) -> Vec<usize>
n of the indices below files, ascending, drawn at random from seed: every index when there are no more than n. The same seed draws the same sample.