pub fn sniff(head: &[u8]) -> (FileFormat, Option<CompressionFormat>)Expand description
The format and compression the first bytes of a file say it is: compression by its
magic numbers, then whatever a format’s signature says ([crate::readers::sniff]),
and text no format claims as JSON, CSV or TSV on evidence, lines otherwise
(crate::lines::guess). head is all there is when it is shorter than [HEAD].