FileScan

Type Alias FileScan 

pub type FileScan = Arc<dyn Fn(&[String], &[PlSmallStr]) -> PolarsResult<LazyFrame> + Send + Sync>;
Builds a scan of some of a dataset’s files as the full scan reads them, the second argument’s columns read as text from every file instead of the majority type.

Aliased Type

pub struct FileScan { /* private fields */ }