pub const fn tab(format: FileFormat) -> &'static strExpand description
The name of format’s tab of the Info panel, as its descriptor says it: a reader
names its Detail by this, so the descriptor is the one place that says it.
pub const fn tab(format: FileFormat) -> &'static strThe name of format’s tab of the Info panel, as its descriptor says it: a reader
names its Detail by this, so the descriptor is the one place that says it.