pub fn table_number_format(
settings: &NumberFormatSettings,
column: &str,
dtype: &DataType,
) -> NumberFormatExpand description
The format the table prints column in, plain where it prints it unformatted.
pub fn table_number_format(
settings: &NumberFormatSettings,
column: &str,
dtype: &DataType,
) -> NumberFormatThe format the table prints column in, plain where it prints it unformatted.