step

Function step 

pub fn step(xs: &[f64], place: &PlotPlace, from: f64, to: Move) -> Option<f64>
Where the cursor at from goes: to the first point of the next column that has one, so sparse points are stepped one by one and dense ones a column at a time; or to the first or last point.