lines

Function lines 

pub fn lines(
    doc: &Documented,
    expanded: &HashSet<String>,
    measured: Option<u64>,
) -> Vec<DocLine>
The page’s lines for doc, with the legends of expanded columns open. measured is the size something has measured, if any.