pub fn compared(
modal: &InspectorModal,
state: &DataTableState,
row: &InspectRow,
) -> Option<Compared>Expand description
What Compare puts beside row, while it is on.
pub fn compared(
modal: &InspectorModal,
state: &DataTableState,
row: &InspectRow,
) -> Option<Compared>What Compare puts beside row, while it is on.