pub fn list_window(
n: usize,
sel: usize,
offset: usize,
cap: usize,
) -> (usize, bool, bool)Expand description
Where the list starts for cap slots of n items, focus at sel, last start
offset; and whether the first and last slots count items above and below.