pub fn shown<'a>(
field: &InspectField,
row: &'a InspectRow,
read: Option<&'a FieldRead>,
state: &DataTableState,
) -> Shown<'a>Expand description
field of row: from the buffer, or from what was read for the row.
pub fn shown<'a>(
field: &InspectField,
row: &'a InspectRow,
read: Option<&'a FieldRead>,
state: &DataTableState,
) -> Shown<'a>field of row: from the buffer, or from what was read for the row.