render

Function render 

pub fn render(
    area: Rect,
    buf: &mut Buffer,
    modal: &mut PivotMeltModal,
    ctx: &RenderContext,
)
Draw the builder over area, the whole screen above the status footer, which carries its keys (hints).