pub fn render_list(
config: &DataQualityWidgetConfig<'_>,
table_state: &mut TableState,
area: Rect,
buf: &mut Buffer,
)Expand description
Every column of the scope, each with its declared rules; the key named under it.
pub fn render_list(
config: &DataQualityWidgetConfig<'_>,
table_state: &mut TableState,
area: Rect,
buf: &mut Buffer,
)Every column of the scope, each with its declared rules; the key named under it.