Module retype

Module retype 

The type picker and the combine form: one Surface each over the table.

Functions

render_combine
The combine form over area.
render_retype
The type picker over area: the types, or a type’s formats with what each makes of the column’s first value, and a format typed with what it makes of it.