render_retype

Function render_retype 

pub fn render_retype(
    area: Rect,
    buf: &mut Buffer,
    modal: &RetypeModal,
    ctx: &RenderContext,
)
The type picker over area: the types, or a type’s formats with what each makes of the column’s first value, and a format typed with what it makes of it.