The table widget: draws a DataTableState’s page, fitting the columns to the
width, and records what it drew for the clicks that follow.
The table widget: draws a DataTableState’s page, fitting the columns to the
width, and records what it drew for the clicks that follow.