nice_steps

Function nice_steps 

pub fn nice_steps(lo: f64, hi: f64, finest: f64, whole: bool) -> Vec<f64>
The 1-2-5 steps for an axis from lo to hi, finest first: from the finest no finer than finest to the first that spans the whole axis. 25, 250 and so on step between 20 and 50 where they need no more places than their neighbors. A whole axis steps by whole numbers only.