pub fn select(
results: &[(DistributionType, FitOutcome)],
counts: bool,
) -> DistributionTypeExpand description
The family the values are consistent with, or Unknown when all are rejected: the
lowest AIC among the unrejected, preferring a count distribution for counts (density
and probability are not on one scale).