pub fn column_choices(
report: &QualityReport,
results: &DataQualityResults,
) -> Vec<(String, usize)>Expand description
The columns a report can be narrowed to, each with how many findings name it, in the results’ column order.
pub fn column_choices(
report: &QualityReport,
results: &DataQualityResults,
) -> Vec<(String, usize)>The columns a report can be narrowed to, each with how many findings name it, in the results’ column order.