pub fn window_start(label: &str, every: &str) -> Option<NaiveDateTime>Expand description
Where window label starts, read back from the label a run gave it: the inverse
of time_window_label. None for the rows with no time, and for a label that
is not a window’s.