pub fn stride(
hay: &[u8],
pattern: &Pattern,
hit: u64,
stop: &AtomicBool,
) -> Option<u64>Expand description
The distance between the matches after hit, when the next few are all the same
distance apart: a sync word or a magic that starts every record.