describe_error

Function describe_error 

pub fn describe_error(status: u16, body: &str) -> String
403 AuthorizationPermissionMismatch: ... from an error document, with what fixes the one that trips up people who manage their storage in the Portal.