pub fn polars_provider(configuration: &str) -> PlCredentialProviderExpand description
Polars’ credential provider for a gcloud configuration. One per configuration for
the life of the process: Polars caches stores by provider, so a new provider per
open would build a new store, and a new connection pool, every time.