pub fn parse(
text: &str,
allowed: &dyn Fn(&str) -> bool,
) -> Vec<(String, String)>Expand description
The KEY=value lines of a dotenv file whose key allowed accepts. Handles
export , # comments, and single or double quotes around a value.