pub fn variant_rows(file: &Path, formats: &Registry) -> Vec<Entry>Expand description
The rows of a file a format spec reads as several variants, one a variant, each at
its path inside the file (day.itch/add): opened, it is the file read with
--table. Empty for any other file.