list_preview

Function list_preview 

pub fn list_preview(items: &Series) -> String
How the table previews a list cell: its first ten items, and how many there are when that is not all of them ([a, b...] (12 items)).