pub fn str_value<'a>(value: &AnyValue<'a>) -> Cow<'a, str>Expand description
AnyValue::str_value, which panics on a date past the calendar, with such a
value written as its stored number, and a list or struct holding one written
as nested_compact does.