pub fn decode_at(
bytes: &[u8],
column: &ColumnLayout,
records: &[usize],
) -> PolarsResult<Column>Expand description
The values of column from bytes for records that start at records, in that
order: each record’s cell is column.start bytes into it, and stride is not used.
For records that are not evenly spaced, such as the messages of a log, found by an
index. A cell past the end of bytes is an error.