pub fn integers(
column: &ColumnLayout,
ints: Vec<Option<i128>>,
) -> PolarsResult<Series>Expand description
Integers as their column means them: plain at its width, or as its logical says
(a datetime, a duration, a factor and offset, an enum’s labels). Public for readers
that find their integers some other way, such as bit fields of CAN signals.