pub fn key<T: Form + ?Sized>( form: &mut T, event: &KeyEvent, ) -> FormKey<T::Field>
What event does to form while no picker is open. Focus moves happen here; everything else is returned for the modal to do.
event
form