pub fn split_place(path: &Path) -> Option<(PathBuf, String)>
The cache directory and the split a path inside one names (cache/test), as the home screen lists it and recents record it. None for a path that is there.
cache/test
None