pub fn split(path: &Path) -> Option<(PathBuf, String)>Expand description
The file and the table a path inside a file of tables names, the inverse of
place: shop.db/orders is the table orders of shop.db, and shop.db/a/b the
table a/b. None for a path that is there, or that is inside no such file.