pub fn add(file: &Path, dataset: &NewDataset) -> Result<String>Expand description
Append dataset to the catalog in file, creating the file when there is none.
Returns its id. The rest of the file is kept as written.
pub fn add(file: &Path, dataset: &NewDataset) -> Result<String>Append dataset to the catalog in file, creating the file when there is none.
Returns its id. The rest of the file is kept as written.