pub fn opens_as_json(text: &str) -> boolExpand description
Whether Enter offers to open text as JSON: it reads as an object or array and
is not over JSON_MAX_BYTES, past which Enter shows more of it instead.
pub fn opens_as_json(text: &str) -> boolWhether Enter offers to open text as JSON: it reads as an object or array and
is not over JSON_MAX_BYTES, past which Enter shows more of it instead.