refuse_paths

Function refuse_paths 

pub fn refuse_paths(paths: &[PathBuf], options: &OpenOptions) -> Option<String>
Why paths cannot be followed as options ask, before anything is read: only one local file, or standard input, can be.