pub fn display_width(
fmt: &CellFormatter,
value: &AnyValue<'_>,
scratch: &mut String,
) -> usizeExpand description
A value’s on-screen cells without building its string where possible (integers); others are rendered and measured as the table measures them.