Module query

Module query 

Modules

sql_group
What a SQL GROUP BY result was grouped from, read from the statement itself, so Enter on a row of the result can show the rows behind it.

Structs

ParsedQuery
A parsed q query, ready to apply to a LazyFrame.

Functions

parse_query
parse_query_over
parse_query for data of schema: timestamp literals against zoned columns read in that zone, and temporal columns compared with quoted text are errors.
sanitize_query_error
Convert Polars-specific error messages to user-friendly query errors.