Structs
- Parsed
Query - A parsed q query, ready to apply to a LazyFrame.
Functions
- parse_
query - parse_
query_ over parse_queryfor data ofschema: a timestamp literal compared with a column that has a time zone reads as a clock in that zone, and a temporal column compared with quoted text is an error.- sanitize_
query_ error - Convert Polars-specific error messages to user-friendly query errors.