Module query

Module query 

Structs

ParsedQuery
A parsed q query, ready to apply to a LazyFrame.

Functions

parse_query
parse_query_over
parse_query for data of schema: a timestamp literal compared with a column that has a time zone reads as a clock in that zone, and a temporal column compared with quoted text is an error.
sanitize_query_error
Convert Polars-specific error messages to user-friendly query errors.