pub fn passed_through(
sql: &str,
columns: &[&str],
result: &[&str],
) -> Vec<(String, String)>Expand description
The columns of sql’s result, named in result, that are columns of the table it
reads (named in columns) unchanged, renamed or not: each result name with the
column’s. Only a plain statement’s select list is read: *, a column, or a column
AS a name. Anything else, or a statement that is not plain, gives none.