pub fn parse_mc_config(text: &str) -> Vec<ToolServer>Expand description
Aliases from an mc config.json (format version 10), leaving out the ones with no
keys or mc’s placeholders, and the public play server mc adds by default.
pub fn parse_mc_config(text: &str) -> Vec<ToolServer>Aliases from an mc config.json (format version 10), leaving out the ones with no
keys or mc’s placeholders, and the public play server mc adds by default.