pub fn plan(
sql: &str,
columns: &[&str],
result_width: usize,
) -> Option<GroupPlan>Expand description
The plan for sql, run against a table whose columns are columns and giving a
result result_width columns wide, or None when the statement is not a grouping
whose rows can be traced back reliably.