The text parse reads back to exactly value, a value of dtype: what + and
- put in a filter. A float is its shortest exact decimal, a date and time its
clock in the column’s zone to the last digit (with its offset where that clock
happens twice). None for a null, and for a type parse does not read.