pub fn height(modal: &ChartExportModal) -> u16Expand description
Rows the dialog wants: the fields the chart’s type shows, a blank and the status line, the blank row and the footer, the border.
pub fn height(modal: &ChartExportModal) -> u16Rows the dialog wants: the fields the chart’s type shows, a blank and the status line, the blank row and the footer, the border.