pub type FileScan = Arc<dyn Fn(&[String], &[PlSmallStr]) -> PolarsResult<LazyFrame> + Send + Sync>;Expand description
Builds a scan of some of a dataset’s files, as the full scan reads them, with the columns named in the second argument read as text from every file rather than as the type most rows have.
Aliased Type
pub struct FileScan { /* private fields */ }