list_window

Function list_window 

pub fn list_window(
    n: usize,
    sel: usize,
    offset: usize,
    cap: usize,
) -> (usize, bool, bool)
Where the list starts, given cap slots for n items with the focus on sel and the list last starting at offset; and whether the first slot counts the items above and the last the items below.