pub fn refresh_list(
modal: &mut InspectorModal,
state: &DataTableState,
row: Option<&InspectRow>,
)Expand description
Keep the fields listed for row, the row shown, as visible_fields has them:
worked out again only when something they depend on changed.